@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.1.4.1.2.3 $
+
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
@@ -25,38 +25,35 @@
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
 // ------------------------------------------------------------------------- //
 
-if ( ! defined( 'XOOPS_ROOT_PATH' ) ) exit();
+defined('XOOPS_ROOT_PATH') || exit('XOOPS root path not defined');
 
 /**
- *
- * XmlRpcTransform composer class for Book type
- *
- *
+ * XmlRpcTransform composer class for Book type.
  */
 class XNPBookXmlRpcTransformCompo extends XooNIpsXmlRpcTransformCompo
 {
-    function XNPBookXmlRpcTransformCompo() 
+    public function __construct()
     {
-        parent::XooNIpsXmlRpcTransformCompo('xnpbook');
+        parent::__construct('xnpbook');
     }
 
     /**
      * override getObject to order author.
-     * 
+     *
      * @see XooNIpsXmlRpcTransformCompo::getObject
      *
      * @param array associative array of XML-RPC argument
+     *
      * @return XNPBookOrmAuthor
      */
-    function getObject($in_array) 
+    public function getObject($in_array)
     {
-        $obj=parent::getObject($in_array);
-        $authors=&$obj->getVar('author');
-        for( $i=0; $i < count($authors); $i++){
+        $obj = parent::getObject($in_array);
+        $authors = &$obj->getVar('author');
+        for ($i = 0; $i < count($authors); ++$i) {
             $authors[$i]->set('author_order', $i);
         }
+
         return $obj;
     }
-
 }
-?>
