@@ -1,8 +1,8 @@
 <?php
-// $Revision: 1.1.8.2 $
+
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
-//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  Copyright (C) 2005-2013 RIKEN, Japan All rights reserved.                //
 //  http://xoonips.sourceforge.jp/                                           //
 // ------------------------------------------------------------------------- //
 //  This program is free software; you can redistribute it and/or modify     //
@@ -25,22 +25,20 @@
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
 // ------------------------------------------------------------------------- //
 /* constant strings
- * $Revision: 1.1.8.2 $
  */
 
 // _MI_<MODULENAME>_<STRINGNAME>
 // The name of this module
-define( '_MI_XNPBOOK_NAME', 'XooNIps Book Item Type Module' );
+define('_MI_XNPBOOK_NAME', 'XooNIps Book Item Type Module');
 // A brief description of this module
-define( '_MI_XNPBOOK_DESC', 'XooNIps Book Item Type Module' );
+define('_MI_XNPBOOK_DESC', 'XooNIps Book Item Type Module');
 
 // Names of admin menu items
-define( '_MI_XNPBOOK_CFG_DL_LIMIT', 'ϿԤˤ󥪥ץѤĤޤ' );
-define( '_MI_XNPBOOK_CFG_DL_LIMIT_DESC', '' );
-define( '_MI_XNPBOOK_CFG_ACCESSKEY', 'Access key for Amazon Product Advertising API' );
-define( '_MI_XNPBOOK_CFG_ACCESSKEY_DESC', '' );
-define( '_MI_XNPBOOK_CFG_SACCESSKEY', 'Secret access key for Amazon Product Advertising API' );
-define( '_MI_XNPBOOK_CFG_SACCESSKEY_DESC', '' );
-
-
-?>
+define('_MI_XNPBOOK_CFG_DL_LIMIT', 'ϿԤˤ󥪥ץѤĤޤ');
+define('_MI_XNPBOOK_CFG_DL_LIMIT_DESC', '');
+define('_MI_XNPBOOK_CFG_ACCESSKEY', 'Access key for Amazon Product Advertising API');
+define('_MI_XNPBOOK_CFG_ACCESSKEY_DESC', '');
+define('_MI_XNPBOOK_CFG_SAKEY', 'Secret access key for Amazon Product Advertising API');
+define('_MI_XNPBOOK_CFG_SAKEY_DESC', '');
+define('_MI_XNPBOOK_CFG_ASSOCIATE', 'Secret associate tag for Amazon Product Advertising API');
+define('_MI_XNPBOOK_CFG_ASSOCIATE_DESC', '');
