@@ -1,8 +1,8 @@
 <?php
-// $Revision: 1.1.2.4 $
+
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
-//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
 //  http://xoonips.sourceforge.jp/                                           //
 // ------------------------------------------------------------------------- //
 //  This program is free software; you can redistribute it and/or modify     //
@@ -25,38 +25,40 @@
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
 // ------------------------------------------------------------------------- //
 
-if ( ! defined( 'XOOPS_ROOT_PATH' ) ) exit();
+defined('XOOPS_ROOT_PATH') || exit('XOOPS root path not defined');
 
-include_once XOOPS_ROOT_PATH . '/modules/xoonips/class/xoonips_compo_item.class.php';
-include_once XOOPS_ROOT_PATH . '/modules/xnpfiles/iteminfo.php';
+require_once XOOPS_ROOT_PATH.'/modules/xoonips/class/xoonips_compo_item.class.php';
+require_once XOOPS_ROOT_PATH.'/modules/xnpfiles/iteminfo.php';
 
 /**
- *
  * @brief Handler object that create,insert,update,get,delete XNPFilesCompo object.
- *
  */
 class XNPFilesCompoHandler extends XooNIpsItemInfoCompoHandler
 {
-    function XNPFilesCompoHandler(&$db) 
+    public function __construct(&$db)
     {
-        parent::XooNIpsItemInfoCompoHandler($db, 'xnpfiles');
+        parent::__construct($db, 'xnpfiles');
     }
-    function &create() 
+
+    public function &create()
     {
         $files = new XNPFilesCompo();
+
         return $files;
     }
 
     /**
-     * return template filename
-     * 
-     * @param string $type defined symbol 
-     *  XOONIPS_TEMPLATE_TYPE_TRANSFER_ITEM_DETAIL
-     *  or XOONIPS_TEMPLATE_TYPE_TRANSFER_ITEM_LISTL
-     * @return template filename
+     * return template filename.
+     *
+     * @param string $type defined symbol
+     *                     XOONIPS_TEMPLATE_TYPE_TRANSFER_ITEM_DETAIL
+     *                     or XOONIPS_TEMPLATE_TYPE_TRANSFER_ITEM_LISTL
+     *
+     * @return string filename
      */
-    function getTemplateFileName($type){
-        switch( $type ){
+    public function getTemplateFileName($type)
+    {
+        switch ($type) {
         case XOONIPS_TEMPLATE_TYPE_TRANSFER_ITEM_DETAIL:
             return 'xnpfiles_transfer_item_detail.html';
         case XOONIPS_TEMPLATE_TYPE_TRANSFER_ITEM_LIST:
@@ -65,56 +67,58 @@ class XNPFilesCompoHandler extends XooNIpsItemInfoCompoHandler
             return '';
         }
     }
-    
+
     /**
-     * return template variables of item
-     * 
-     * @param string $type defined symbol 
-     *  XOONIPS_TEMPLATE_TYPE_TRANSFER_ITEM_DETAIL
-     *  , XOONIPS_TEMPLATE_TYPE_TRANSFER_ITEM_LIST
-     *  or XOONIPS_TEMPLATE_TYPE_ITEM_LIST
-     * @param int $item_id
-     * @param int $uid user id who get item
+     * return template variables of item.
+     *
+     * @param string $type    defined symbol
+     *                        XOONIPS_TEMPLATE_TYPE_TRANSFER_ITEM_DETAIL
+     *                        , XOONIPS_TEMPLATE_TYPE_TRANSFER_ITEM_LIST
+     *                        or XOONIPS_TEMPLATE_TYPE_ITEM_LIST
+     * @param int    $item_id
+     * @param int    $uid     user id who get item
+     *
      * @return array of template variables
      */
-    function getTemplateVar($type, $item_id, $uid){
-        $files =& $this->get( $item_id );
-        if ( ! is_object( $files ) ) {
-          return array();
+    public function getTemplateVar($type, $item_id, $uid)
+    {
+        $files = &$this->get($item_id);
+        if (!is_object($files)) {
+            return array();
         }
         $result = $this->getBasicTemplateVar($type, $files, $uid);
-        
-        $detail =& $files -> getVar( 'detail' );
-        $files_file =& $files -> getVar( 'files_file' );
-        switch( $type ){
+
+        $detail = &$files->getVar('detail');
+        $files_file = &$files->getVar('files_file');
+        switch ($type) {
         case XOONIPS_TEMPLATE_TYPE_ITEM_LIST:
-            $result['detail']=$detail->getVarArray('s');
-            $result['files_file']=$files_file->getVarArray('s');
+            $result['detail'] = $detail->getVarArray('s');
+            $result['files_file'] = $files_file->getVarArray('s');
+
             return $result;
         case XOONIPS_TEMPLATE_TYPE_TRANSFER_ITEM_DETAIL:
         case XOONIPS_TEMPLATE_TYPE_ITEM_DETAIL:
         case XOONIPS_TEMPLATE_TYPE_TRANSFER_ITEM_LIST:
-            $result['detail'] = $detail -> getVarArray('s');
-            $files_file = $files -> getVar( 'files_file' );
-            if( $files_file -> get( 'item_id' ) == $item_id ){
-                $result['detail']['files_file'] = $this -> getAttachmentTemplateVar($files -> getVar( 'files_file' ) );
+            $result['detail'] = $detail->getVarArray('s');
+            $files_file = $files->getVar('files_file');
+            if ($files_file->get('item_id') == $item_id) {
+                $result['detail']['files_file'] = $this->getAttachmentTemplateVar($files->getVar('files_file'));
             }
+
             return $result;
         }
+
         return $result;
     }
 }
 
 /**
- *
  * @brief Data object that have one ore more XooNIpsTableObject for Files type.
- *
  */
 class XNPFilesCompo extends XooNIpsItemInfoCompo
 {
-    function XNPFilesCompo() 
+    public function __construct()
     {
-        parent::XooNIpsItemInfoCompo('xnpfiles');
+        parent::__construct('xnpfiles');
     }
 }
-?>
