@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.1.4.1.2.4 $
+
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
@@ -24,53 +24,50 @@
 //  along with this program; if not, write to the Free Software              //
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
 // ------------------------------------------------------------------------- //
-if ( ! defined( 'XOOPS_ROOT_PATH' ) ) {
-  exit();
-}
+defined('XOOPS_ROOT_PATH') || exit('XOOPS root path not defined');
 
 //  Install script for XooNIps Stimulus item type module
-function xoops_module_install_xnpstimulus( $xoopsMod ) {
-  global $xoopsDB;
+function xoops_module_install_xnpstimulus($xoopsMod)
+{
+    global $xoopsDB;
 
-  // register itemtype
-  $table = $xoopsDB->prefix( 'xoonips_item_type' );
-  $mid = $xoopsMod->getVar( 'mid' );
-  $sql = "INSERT INTO $table ( name, display_name, mid, viewphp ) VALUES ( 'xnpstimulus', 'Stimulus', $mid, 'xnpstimulus/include/view.php' )";
-  if ( $xoopsDB->query( $sql ) == FALSE ) {
-    // cannot register itemtype
-    return false;
-  }
-
-  // register filetype
-  $table = $xoopsDB->prefix( 'xoonips_file_type' );
-  $mid = $xoopsMod->getVar( 'mid' );
-  $sql = "INSERT INTO $table ( name, display_name, mid ) VALUES ( 'stimulus_data', 'Stimulus Data', $mid )";
-  if ( $xoopsDB->query( $sql ) == FALSE ) {
-    // cannot register itemtype
-    return false;
-  }
-
-  // Delete 'Module Access Rights' from all groups
-  // This allows to remove redundant module name in Main Menu
-  $member_handler =& xoops_gethandler( 'member' );
-  $gperm_handler =& xoops_gethandler( 'groupperm' );
-  $groups =& $member_handler->getGroupList();
-  foreach ( $groups as $groupid2 => $groupname ) {
-    if ( $gperm_handler->checkRight( 'module_read', $mid, $groupid2 ) ) {
-      $criteria = new CriteriaCompo();
-      $criteria->add( new Criteria( 'gperm_groupid', $groupid2 ) );
-      $criteria->add( new Criteria( 'gperm_itemid', $mid ) );
-      $criteria->add( new Criteria( 'gperm_name', 'module_read' ) );
-
-      $objects =& $gperm_handler->getObjects( $criteria );
-      if ( count( $objects ) == 1 ) {
-        $gperm_handler->delete( $objects[0] );
-      }
+    // register itemtype
+    $table = $xoopsDB->prefix('xoonips_item_type');
+    $mid = $xoopsMod->getVar('mid');
+    $sql = "INSERT INTO $table ( name, display_name, mid, viewphp ) VALUES ( 'xnpstimulus', 'Stimulus', $mid, 'xnpstimulus/include/view.php' )";
+    if (false == $xoopsDB->query($sql)) {
+        // cannot register itemtype
+        return false;
     }
-  }
 
-  // $item_type_id = $xoopsDB->getInsertId();
-  return true;
+    // register filetype
+    $table = $xoopsDB->prefix('xoonips_file_type');
+    $mid = $xoopsMod->getVar('mid');
+    $sql = "INSERT INTO $table ( name, display_name, mid ) VALUES ( 'stimulus_data', 'Stimulus Data', $mid )";
+    if (false == $xoopsDB->query($sql)) {
+        // cannot register itemtype
+        return false;
+    }
+
+    // Delete 'Module Access Rights' from all groups
+    // This allows to remove redundant module name in Main Menu
+    $member_handler = &xoops_gethandler('member');
+    $gperm_handler = &xoops_gethandler('groupperm');
+    $groups = &$member_handler->getGroupList();
+    foreach ($groups as $groupid2 => $groupname) {
+        if ($gperm_handler->checkRight('module_read', $mid, $groupid2)) {
+            $criteria = new CriteriaCompo();
+            $criteria->add(new Criteria('gperm_groupid', $groupid2));
+            $criteria->add(new Criteria('gperm_itemid', $mid));
+            $criteria->add(new Criteria('gperm_name', 'module_read'));
+
+            $objects = &$gperm_handler->getObjects($criteria);
+            if (1 == count($objects)) {
+                $gperm_handler->delete($objects[0]);
+            }
+        }
+    }
+
+    // $item_type_id = $xoopsDB->getInsertId();
+    return true;
 }
-
-?>
