@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.1.2.4 $
+
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
@@ -24,45 +24,33 @@
 //  along with this program; if not, write to the Free Software              //
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
 // ------------------------------------------------------------------------- //
-if ( ! defined( 'XOOPS_ROOT_PATH' ) ) {
-  exit();
-}
+defined('XOOPS_ROOT_PATH') || exit('XOOPS root path not defined');
 
 // check token ticket
-require_once( '../class/base/gtickets.php' );
+require_once '../class/base/gtickets.php';
 $ticket_area = 'xoonips_admin_policy_item_public';
-if ( ! $xoopsGTicket->check( true, $ticket_area, false ) ) {
-  redirect_header( $xoonips_admin['mypage_url'], 3, $xoopsGTicket->getErrors() );
-  exit();
+if (!$xoopsGTicket->check(true, $ticket_area, false)) {
+    redirect_header($xoonips_admin['mypage_url'], 3, $xoopsGTicket->getErrors());
+    exit();
 }
 
 // get variables
 $post_keys = array(
-  'download_file_compression' => array(
-    's',
-    false,
-    true,
-  ),
-  'item_show_optional' => array(
-    's',
-    false,
-    true,
-  ),
+    'download_file_compression' => array('s', false, true),
+    'item_show_optional' => array('s', false, true),
 );
-$post_vals = xoonips_admin_get_requests( 'post', $post_keys );
+$post_vals = xoonips_admin_get_requests('post', $post_keys);
 
 // set config keys
 $config_keys = array();
-foreach ( $post_keys as $key => $attributes ) {
-  list( $data_type, $is_array, $required ) = $attributes;
-  $config_keys[$key] = $data_type;
+foreach ($post_keys as $key => $attributes) {
+    list($data_type, $is_array, $required) = $attributes;
+    $config_keys[$key] = $data_type;
 }
 
 // update db values
-foreach ( $config_keys as $key => $type ) {
-  xoonips_admin_set_config( $key, $post_vals[$key], $type );
+foreach ($config_keys as $key => $type) {
+    xoonips_admin_set_config($key, $post_vals[$key], $type);
 }
 
-redirect_header( $xoonips_admin['mypage_url'].'&amp;action=public', 3, _AM_XOONIPS_MSG_DBUPDATED );
-
-?>
+redirect_header($xoonips_admin['mypage_url'].'&amp;action=public', 3, _AM_XOONIPS_MSG_DBUPDATED);
