@@ -1,8 +1,8 @@
 <?php
-// $Revision: 1.1.10.1.2.4 $
+
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
-//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
 //  http://xoonips.sourceforge.jp/                                           //
 // ------------------------------------------------------------------------- //
 //  This program is free software; you can redistribute it and/or modify     //
@@ -27,19 +27,23 @@
 
 // advanced search form for add to index
 
-include 'include/common.inc.php';
+require 'include/common.inc.php';
 
-$pankuzu = "";
+// access permission check
+if (!$xoopsUser) {
+    redirect_header('user.php', 3, _MD_XOONIPS_ITEM_FORBIDDEN);
+    exit();
+}
+
+$pankuzu = '';
 
 // disable to link index tree
 $xoonipsURL = '';
 
 $xoopsOption['template_main'] = 'xoonips_advanced_search_add_to_index.html';
 
-include XOOPS_ROOT_PATH.'/header.php';
+require XOOPS_ROOT_PATH.'/header.php';
 
-include 'include/advanced_search.inc.php';
+require 'include/advanced_search.inc.php';
 
-include XOOPS_ROOT_PATH.'/footer.php';
-
-?>
+require XOOPS_ROOT_PATH.'/footer.php';
