@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.1.4.1.2.11 $
+
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
@@ -25,41 +25,43 @@
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
 // ------------------------------------------------------------------------- //
 
-include_once XOOPS_ROOT_PATH . '/modules/xoonips/class/base/logic.class.php';
+require_once XOOPS_ROOT_PATH.'/modules/xoonips/class/base/logic.class.php';
 
 /**
- *
- * subclass of XooNIpsLogic(searchItem)
- *
+ * subclass of XooNIpsLogic(searchItem).
  */
 class XooNIpsLogicSearchItem extends XooNIpsLogic
 {
-    function getSearchCacheIdByQuery($query) 
+    public function getSearchCacheIdByQuery($query)
     {
         if (isset($_SESSION['xoonips_search_cache']) && isset($_SESSION['xoonips_search_cache']["_$query"])) {
             return $_SESSION['xoonips_search_cache']["_$query"];
         }
+
         return false;
     }
-    function putSearchCache($query, $search_cache_id) 
+
+    public function putSearchCache($query, $search_cache_id)
     {
         if (!isset($_SESSION['xoonips_search_cache'])) {
             $_SESSION['xoonips_search_cache'] = array();
         }
         $_SESSION['xoonips_search_cache']["_$query"] = $search_cache_id;
     }
-    function deleteSearchCache($search_cache_id) 
+
+    public function deleteSearchCache($search_cache_id)
     {
-        foreach ( array_keys($_SESSION['xoonips_search_cache']) as $key ){
-            if ( $_SESSION['xoonips_search_cache'][$key] == $search_cache_id ){
+        foreach (array_keys($_SESSION['xoonips_search_cache']) as $key) {
+            if ($_SESSION['xoonips_search_cache'][$key] == $search_cache_id) {
                 unset($_SESSION['xoonips_search_cache'][$key]);
+
                 return;
             }
         }
     }
 
     /**
-     * execute searchItem
+     * execute searchItem.
      *
      * @param[in]  $vars[0] session ID
      * @param[in]  $vars[1] query string
@@ -74,36 +76,50 @@ class XooNIpsLogicSearchItem extends XooNIpsLogic
      * @param[out] $response->success[n]['id'] item id of matched item
      * @param[out] $response->success[n]['matchfor'] bit flag represents what part of item matched
      */
-    function execute(&$vars, &$response) 
+    public function execute(&$vars, &$response)
     {
         // parameter check
         $error = &$response->getError();
-        if (count($vars) > 6) $error->add(XNPERR_EXTRA_PARAM);
-        if (count($vars) < 6) $error->add(XNPERR_MISSING_PARAM);
-        //
-        if (isset($vars[0]) && strlen($vars[0]) > 32) $error->add(XNPERR_INVALID_PARAM, 'too long parameter 1');
+        if (count($vars) > 6) {
+            $error->add(XNPERR_EXTRA_PARAM);
+        }
+        if (count($vars) < 6) {
+            $error->add(XNPERR_MISSING_PARAM);
+        }
+
+        if (isset($vars[0]) && strlen($vars[0]) > 32) {
+            $error->add(XNPERR_INVALID_PARAM, 'too long parameter 1');
+        }
         $ar = explode(':', $vars[1]);
-        if (count($ar) < 2 || !in_array($ar[0], array(
-            'index',
-            'keyword'
-        ))) $error->add(XNPERR_INVALID_PARAM, 'bad query parameter 2');
-        if (!is_int($vars[2]) && !ctype_digit($vars[2])) $error->add(XNPERR_INVALID_PARAM, 'not integer parameter 2');
-        if (!is_int($vars[3]) && !ctype_digit($vars[3])) $error->add(XNPERR_INVALID_PARAM, 'not integer parameter 3');
-        if (!in_array($vars[4], array(
+        if (count($ar) < 2 || !in_array($ar[0], array('index', 'keyword'))) {
+            $error->add(XNPERR_INVALID_PARAM, 'bad query parameter 2');
+        }
+        if (!is_int($vars[2]) && !ctype_digit($vars[2])) {
+            $error->add(XNPERR_INVALID_PARAM, 'not integer parameter 2');
+        }
+        if (!is_int($vars[3]) && !ctype_digit($vars[3])) {
+            $error->add(XNPERR_INVALID_PARAM, 'not integer parameter 3');
+        }
+        if (!in_array(
+            $vars[4], array(
             'title',
             'ext_id',
             'last_modified_date',
             'registration_date',
-            'creation_date'
-        ))) $error->add(XNPERR_INVALID_PARAM, 'unknown sort key parameter 4');
-        if (!in_array($vars[5], array(
-            'asc',
-            'desc'
-        ))) $error->add(XNPERR_INVALID_PARAM, 'unknown sort order parameter 5');
-        //
+            'creation_date',
+            )
+        )
+        ) {
+            $error->add(XNPERR_INVALID_PARAM, 'unknown sort key parameter 4');
+        }
+        if (!in_array($vars[5], array('asc', 'desc'))) {
+            $error->add(XNPERR_INVALID_PARAM, 'unknown sort order parameter 5');
+        }
+
         if ($error->get(0)) {
             // return if parameter error
             $response->setResult(false);
+
             return;
         } else {
             $sessionid = $vars[0];
@@ -117,111 +133,114 @@ class XooNIpsLogicSearchItem extends XooNIpsLogic
         if (!$result) {
             $response->setResult(false);
             $error->add(XNPERR_INVALID_SESSION);
+
             return false;
         }
         $response->setResult(false);
-        
+
         // convert ($start, $limit, $sortkey, $ascdesc) to ($criteria, $join_sort_table)
         $criteria = new CriteriaCompo();
         $criteria->setOrder($ascdesc);
         $criteria->setStart($start);
         $criteria->setLimit($limit);
         switch ($sortkey) {
-            case 'title':
-                $join_sort_table = 'xoonips_item_title';
-                $criteria->add(new Criteria('title_id', 0));
-                $criteria->setSort('title');
-                break;
+        case 'title':
+            $join_sort_table = 'xoonips_item_title';
+            $criteria->add(new Criteria('title_id', 0));
+            $criteria->setSort('title');
+            break;
 
-            case 'ext_id':
-                $join_sort_table = false;
-                $criteria->setSort('doi');
-                break;
+        case 'ext_id':
+            $join_sort_table = false;
+            $criteria->setSort('doi');
+            break;
 
-            case 'last_modified_date':
-                $join_sort_table = false;
-                $criteria->setSort('last_update_date');
-                break;
+        case 'last_modified_date':
+            $join_sort_table = false;
+            $criteria->setSort('last_update_date');
+            break;
 
-            case 'registration_date':
-                $join_sort_table = false;
-                $criteria->setSort('creation_date');
-                break;
+        case 'registration_date':
+            $join_sort_table = false;
+            $criteria->setSort('creation_date');
+            break;
 
-            case 'creation_date':
-                $join_sort_table = false;
-                $criteria->setSort(array(
-                    'publication_year',
-                    'publication_month',
-                    'publication_mday'
-                ));
-                break;
+        case 'creation_date':
+            $join_sort_table = false;
+            $criteria->setSort(array('publication_year', 'publication_month', 'publication_mday'));
+            break;
 
-            default:
-                $error->add(XNPERR_INVALID_PARAM, 'unknown sort key parameter 4');
-                $response->setResult(false);
-                return false;
+        default:
+            $error->add(XNPERR_INVALID_PARAM, 'unknown sort key parameter 4');
+            $response->setResult(false);
+
+            return false;
                 break;
         }
-        
+
         // get valid item_type_ids -> $criteria
         $factory = &XooNIpsLogicFactory::getInstance();
-        $logic = &$factory->create("getItemTypes");
-        $vars = array( $sessionid );
+        $logic = &$factory->create('getItemTypes');
+        $vars = array($sessionid);
         $logic->execute($vars, $response);
-        if ( $response->getResult() == false ){
+        if (false == $response->getResult()) {
             return false;
         }
         $itemtypes = $response->getSuccess();
-        if ( count($itemtypes) == 0 ){
+        if (0 == count($itemtypes)) {
             // no itemtype found. return empty array.
             $ar = array();
             $response->setSuccess($ar);
             $response->setResult(true);
+
             return true;
         }
         $itemtype_ids = array();
-        foreach ( $itemtypes as $itemtype ){
+        foreach ($itemtypes as $itemtype) {
             $itemtype_ids[] = $itemtype->get('item_type_id');
         }
-        $criteria->add( new Criteria('item_type_id', '('.implode(',', $itemtype_ids).')', 'IN'));
-        
-        if (substr($query, 0, 6) == 'index:') {
+        $criteria->add(new Criteria('item_type_id', '('.implode(',', $itemtype_ids).')', 'IN'));
+
+        if ('index:' == substr($query, 0, 6)) {
             // index id -> search_cache_items
             $index_id = substr($query, 6);
             if (!ctype_digit($index_id)) {
                 $error->add(XNPERR_INVALID_PARAM, "bad index id(index_id=$index_id)");
                 $response->setResult(false);
+
                 return false;
             }
             $criteria->add(new Criteria('index_id', $index_id));
-            $index_handler =& xoonips_getormhandler('xoonips', 'index');
+            $index_handler = &xoonips_getormhandler('xoonips', 'index');
             $index = $index_handler->get($index_id);
-            if (false == $index){
+            if (false == $index) {
                 $error->add(XNPERR_NOT_FOUND, "index not found(index_id=$index_id)");
                 $response->setResult(false);
+
                 return false;
             }
             if (!$index_handler->getPerm($index_id, $uid, 'read')) {
                 $error->add(XNPERR_ACCESS_FORBIDDEN, "forbidden(index_id=$index_id)");
                 $response->setResult(false);
+
                 return false;
             }
             // xoonips_index_item_link <- $join(xoonips_item_basic) <- $join2($join_sort_table)
-            $index_item_link_handler =& xoonips_getormhandler('xoonips', 'index_item_link');
-            $join = new XooNIpsJoinCriteria( 'xoonips_item_basic', 'item_id', 'item_id' );
-            if ( $join_sort_table ){
-                $join2 = new XooNIpsJoinCriteria( $join_sort_table, 'item_id', 'item_id' );
+            $index_item_link_handler = &xoonips_getormhandler('xoonips', 'index_item_link');
+            $join = new XooNIpsJoinCriteria('xoonips_item_basic', 'item_id', 'item_id');
+            if ($join_sort_table) {
+                $join2 = new XooNIpsJoinCriteria($join_sort_table, 'item_id', 'item_id');
                 $join->cascade($join2);
             }
-            
-            $index_item_links =& $index_item_link_handler->getObjects($criteria, false, '', false, $join);
-            $item_compo_handler =& xoonips_getormcompohandler('xoonips', 'item');
-            $search_cache_item_handler =& xoonips_getormhandler('xoonips', 'search_cache_item');
+
+            $index_item_links = &$index_item_link_handler->getObjects($criteria, false, '', false, $join);
+            $item_compo_handler = &xoonips_getormcompohandler('xoonips', 'item');
+            $search_cache_item_handler = &xoonips_getormhandler('xoonips', 'search_cache_item');
             $search_cache_items = array();
-            foreach($index_item_links as $index_item_link) {
-                if ( ! $item_compo_handler->getPerm( $index_item_link->get('item_id'), $uid, 'read' ) )
-                    continue; // no read permission
+            foreach ($index_item_links as $index_item_link) {
+                if (!$item_compo_handler->getPerm($index_item_link->get('item_id'), $uid, 'read')) {
+                    continue;
+                } // no read permission
                 $search_cache_item = $search_cache_item_handler->create();
                 $search_cache_item->set('item_id', $index_item_link->get('item_id'));
                 $search_cache_item->set('matchfor_index', 1);
@@ -231,18 +250,18 @@ class XooNIpsLogicSearchItem extends XooNIpsLogic
             }
             $response->setSuccess($search_cache_items);
             $response->setResult(true);
+
             return true;
-        } else if (substr($query, 0, 8) == 'keyword:') {
+        } elseif ('keyword:' == substr($query, 0, 8)) {
             $search_cache_id = $this->getSearchCacheIdByQuery($query);
-            $search_cache_handler =& xoonips_getormhandler('xoonips', 'search_cache');
-            $eventlog_handler =& xoonips_getormhandler('xoonips', 'event_log');
-            if ( $search_cache_id ){
+            $search_cache_handler = &xoonips_getormhandler('xoonips', 'search_cache');
+            $eventlog_handler = &xoonips_getormhandler('xoonips', 'event_log');
+            if ($search_cache_id) {
                 $search_cache = $search_cache_handler->get($search_cache_id);
-                if ( $search_cache === false ){
+                if (false === $search_cache) {
                     // maybe invalidated.
                     $search_cache_id = false;
-                }
-                else {
+                } else {
                     $c = new CriteriaCompo();
                     $event_type_ids = array( // this events change search result. if one of this event is newer than search cache, don't use search cache.
                         ETID_INSERT_ITEM,
@@ -261,130 +280,141 @@ class XooNIpsLogicSearchItem extends XooNIpsLogic
                     $c->setSort('timestamp');
                     $c->setOrder('desc');
                     $c->setLimit(1);
-                    $event_logs =& $eventlog_handler->getObjects($c);
-                    if (false === $event_logs){
+                    $event_logs = &$eventlog_handler->getObjects($c);
+                    if (false === $event_logs) {
                         $response->setResult(false);
-                        $error->add(XNPERR_SERVER_ERROR, "cannot get event logs");
+                        $error->add(XNPERR_SERVER_ERROR, 'cannot get event logs');
+
                         return false;
-                    }
-                    else if (!empty($event_logs)){
+                    } elseif (!empty($event_logs)) {
                         $search_cache_id = false;
                         // delete old search results from search cache
                         $c = new CriteriaCompo(new Criteria('sess_id', $sessionid));
                         $c->add(new Criteria('unix_timestamp(timestamp)', $event_logs[0]->get('timestamp'), '<'));
-                        $search_caches =& $search_cache_handler->getObjects($c);
-                        if (false === $search_caches){
+                        $search_caches = &$search_cache_handler->getObjects($c);
+                        if (false === $search_caches) {
                             $response->setResult(false);
-                            $error->add(XNPERR_SERVER_ERROR, "cannot get search cache ids");
+                            $error->add(XNPERR_SERVER_ERROR, 'cannot get search cache ids');
+
                             return false;
                         }
-                        $search_cache_item_handler =& xoonips_getormhandler('xoonips', 'search_cache_item');
-                        foreach ( $search_caches as $search_cache ){
+                        $search_cache_item_handler = &xoonips_getormhandler('xoonips', 'search_cache_item');
+                        foreach ($search_caches as $search_cache) {
                             $id = $search_cache->get('search_cache_id');
-                            $this->deleteSearchCache( $id );
+                            $this->deleteSearchCache($id);
                             $search_cache_handler->delete($search_cache);
                             $search_cache_item_handler->deleteAll(new Criteria('search_cache_id', $id));
                         }
                     }
                 }
             }
-            
+
             if (!$search_cache_id) {
                 $search_cache = $search_cache_handler->create();
                 $search_cache->setVar('sess_id', $sessionid, true);
                 if (!$search_cache_handler->insert($search_cache)) {
                     $response->setResult(false);
-                    $error->add(XNPERR_SERVER_ERROR, "cannot create search_cache_id");
+                    $error->add(XNPERR_SERVER_ERROR, 'cannot create search_cache_id');
+
                     return false;
                 }
                 $search_cache_id = $search_cache->get('search_cache_id');
                 $keyword = substr($query, 8);
                 $this->keywordSearch($error, $search_cache_id, $uid, $keyword);
-                if (!$eventlog_handler->recordQuickSearchEvent('all', $keyword)){
-                    $error->add(XNPERR_SERVER_ERROR, "cannot insert event");
+                if (!$eventlog_handler->recordQuickSearchEvent('all', $keyword)) {
+                    $error->add(XNPERR_SERVER_ERROR, 'cannot insert event');
                     $response->setResult(false);
+
                     return false;
                 }
             }
-            
+
             //
             // access permission: ol_public && ( is_moderator || certify_state=certified) || ol_group_only && gid=gulink.gid && ( is_admin || certify_state==certified) || ol_private && uid=uid // how to reuse?
             // -> criteria
             $c = new CriteriaCompo();
             $c->add(new Criteria('open_level', OL_PUBLIC));
-            $member_handler = &xoonips_gethandler('xoonips','member');
+            $member_handler = &xoonips_gethandler('xoonips', 'member');
             if (!$member_handler->isModerator($uid)) {
                 $c->add(new Criteria('certify_state', CERTIFIED));
             }
-            $groups_users_link_handler =& xoonips_getormhandler('xoonips', 'groups_users_link');
-            $links =& $groups_users_link_handler->getObjects(new Criteria('uid', $uid));
-            foreach($links as $link) {
-                $c->add(new Criteria('open_level', OL_GROUP_ONLY) , 'OR');
+            $groups_users_link_handler = &xoonips_getormhandler('xoonips', 'groups_users_link');
+            $links = &$groups_users_link_handler->getObjects(new Criteria('uid', $uid));
+            foreach ($links as $link) {
+                $c->add(new Criteria('open_level', OL_GROUP_ONLY), 'OR');
                 $c->add(new Criteria('gid', $link->get('gid')));
                 if (!$link->get('is_admin')) {
                     $c->add(new Criteria('certify_state', CERTIFIED));
                 }
             }
-            $c->add(new Criteria('open_level', OL_PRIVATE) , 'OR');
+            $c->add(new Criteria('open_level', OL_PRIVATE), 'OR');
             $c->add(new Criteria('tx.uid', $uid));
             $criteria->add($c);
             $criteria->add(new Criteria('search_cache_id', $search_cache_id));
             $criteria->setGroupby('search_cache_item_id');
-            
-            // join: 
+
+            // join:
             //   xoonips_search_cache_item  <-  $join(xoonips_index_item_link)
             //                              <-  $join2(xoonips_index)
             //                              <-  $join3(xoonips_item_basic)
             //                              <-  $join4($join_sort_table)
-            $join = new XooNIpsJoinCriteria( 'xoonips_index_item_link', 'item_id', 'item_id', 'LEFT', 'txil' );
-            $join2 = new XooNIpsJoinCriteria( 'xoonips_index', 'index_id', 'index_id', 'LEFT', 'tx' );
-            $join3 = new XooNIpsJoinCriteria( 'xoonips_item_basic', 'item_id', 'item_id' );
-            $join4 = new XooNIpsJoinCriteria( $join_sort_table, 'item_id', 'item_id' );
-            $join->cascade( $join2, 'txil', true );
-            $join->cascade( $join3, 'xoonips_search_cache_item' );
-            if ( $join_sort_table ){
-                $join->cascade( $join4, 'xoonips_search_cache_item' );
+            $join = new XooNIpsJoinCriteria('xoonips_index_item_link', 'item_id', 'item_id', 'LEFT', 'txil');
+            $join2 = new XooNIpsJoinCriteria('xoonips_index', 'index_id', 'index_id', 'LEFT', 'tx');
+            $join3 = new XooNIpsJoinCriteria('xoonips_item_basic', 'item_id', 'item_id');
+            $join4 = new XooNIpsJoinCriteria($join_sort_table, 'item_id', 'item_id');
+            $join->cascade($join2, 'txil', true);
+            $join->cascade($join3, 'xoonips_search_cache_item');
+            if ($join_sort_table) {
+                $join->cascade($join4, 'xoonips_search_cache_item');
             }
-            $search_cache_item_handler =& xoonips_getormhandler('xoonips', 'search_cache_item');
-            $search_cache_items =& $search_cache_item_handler->getObjects($criteria, false, '', false, $join);
-            if ($search_cache_items === false) {
+            $search_cache_item_handler = &xoonips_getormhandler('xoonips', 'search_cache_item');
+            $search_cache_items = &$search_cache_item_handler->getObjects($criteria, false, '', false, $join);
+            if (false === $search_cache_items) {
                 $error->add(XNPERR_INVALID_PARAM, 'cannot get searched item');
                 $response->setResult(false);
+
                 return false;
             }
             $this->putSearchCache($query, $search_cache_id);
-            
+
             $response->setSuccess($search_cache_items);
             $response->setResult(true);
+
             return true;
         } else {
-            $error->add(XNPERR_INVALID_PARAM, "query must begin with index: or keyword:");
+            $error->add(XNPERR_INVALID_PARAM, 'query must begin with index: or keyword:');
         }
-        
+
         if ($error->get()) {
             $response->setResult(false);
+
             return false;
         }
     }
-    function keywordSearch(&$error, $search_cache_id, $uid, $query) 
+
+    /**
+     * @param string $query
+     */
+    public function keywordSearch(&$error, $search_cache_id, $uid, $query)
     {
-        $search_cache_item_handler =& xoonips_getormhandler('xoonips', 'search_cache_item');
+        $search_cache_item_handler = &xoonips_getormhandler('xoonips', 'search_cache_item');
         // search item
-        $item_type_handler =& xoonips_getormhandler('xoonips', 'item_type');
-        $item_types =& $item_type_handler->getObjects(new Criteria('isnull(mid)', 0));
-        foreach($item_types as $item_type) {
-            $detail_item_handler =& xoonips_getormcompohandler($item_type->get('name') , 'item');
+        $item_type_handler = &xoonips_getormhandler('xoonips', 'item_type');
+        $item_types = &$item_type_handler->getObjects(new Criteria('isnull(mid)', 0));
+        foreach ($item_types as $item_type) {
+            $detail_item_handler = &xoonips_getormcompohandler($item_type->get('name'), 'item');
             if (!$detail_item_handler) {
                 continue;
             }
             $step = 1000;
-            for ($offset = 0;; $offset+= $step) {
+            for ($offset = 0;; $offset += $step) {
                 $item_ids = $detail_item_handler->search($query, $step, $offset, $uid);
-                if ($item_ids === false) {
-                    $error->add(XNPERR_SERVER_ERROR, "cannot search item");
+                if (false === $item_ids) {
+                    $error->add(XNPERR_SERVER_ERROR, 'cannot search item');
+
                     return;
                 }
-                foreach($item_ids as $item_id) {
+                foreach ($item_ids as $item_id) {
                     $search_cache_item = $search_cache_item_handler->create();
                     $search_cache_item->setVar('search_cache_id', $search_cache_id, true);
                     $search_cache_item->setVar('item_id', $item_id, true);
@@ -392,7 +422,8 @@ class XooNIpsLogicSearchItem extends XooNIpsLogic
                     $search_cache_item->setVar('matchfor_item', 1, true);
                     $search_cache_item->setVar('matchfor_file', 0, true);
                     if (!$search_cache_item_handler->insert($search_cache_item)) {
-                        $error->add(XNPERR_SERVER_ERROR, "cannot get items");
+                        $error->add(XNPERR_SERVER_ERROR, 'cannot get items');
+
                         return;
                     }
                 }
@@ -403,37 +434,40 @@ class XooNIpsLogicSearchItem extends XooNIpsLogic
         }
         // search file
         $step = 1000;
-        $search_text_handler =& xoonips_getormhandler('xoonips', 'search_text');
-        $file_handler =& xoonips_getormhandler('xoonips', 'file');
-        for ($offset = 0;; $offset+= $step) {
+        $search_text_handler = &xoonips_getormhandler('xoonips', 'search_text');
+        $file_handler = &xoonips_getormhandler('xoonips', 'file');
+        for ($offset = 0;; $offset += $step) {
             $item_ids = $search_text_handler->search($query, $step, $offset, $uid);
-            if ($item_ids === false) {
-                $error->add(XNPERR_SERVER_ERROR, "cannot search file");
+            if (false === $item_ids) {
+                $error->add(XNPERR_SERVER_ERROR, 'cannot search file');
+
                 return;
             }
             if (count($item_ids)) {
                 // update search_cache_item
                 $criteria = new CriteriaCompo();
-                $criteria->add(new Criteria('item_id', '(' . implode(',', $item_ids) . ')', 'in'));
+                $criteria->add(new Criteria('item_id', '('.implode(',', $item_ids).')', 'in'));
                 $criteria->add(new Criteria('search_cache_id', $search_cache_id));
-                $search_cache_items =& $search_cache_item_handler->getObjects($criteria);
-                if ($search_cache_items === false) {
-                    $error->add(XNPERR_SERVER_ERROR, "cannot get search_cache_item");
+                $search_cache_items = &$search_cache_item_handler->getObjects($criteria);
+                if (false === $search_cache_items) {
+                    $error->add(XNPERR_SERVER_ERROR, 'cannot get search_cache_item');
+
                     return;
                 }
                 $len = count($search_cache_items);
                 $update_item_ids = array();
-                for ($i = 0; $i < $len; $i++) {
+                for ($i = 0; $i < $len; ++$i) {
                     $search_cache_items[$i]->setVar('matchfor_file', 1, true);
                     if (!$search_cache_item_handler->insert($search_cache_items[$i])) {
-                        $error->add(XNPERR_SERVER_ERROR, "cannot update search_cache_item");
+                        $error->add(XNPERR_SERVER_ERROR, 'cannot update search_cache_item');
+
                         return;
                     }
                     $update_item_ids[] = $search_cache_items[$i]->get('item_id');
                 }
                 // insert search_cache_item
                 $insert_item_ids = array_diff($item_ids, $update_item_ids);
-                foreach($insert_item_ids as $item_id) {
+                foreach ($insert_item_ids as $item_id) {
                     $search_cache_item = $search_cache_item_handler->create();
                     $search_cache_item->setVar('search_cache_id', $search_cache_id, true);
                     $search_cache_item->setVar('item_id', $item_id, true);
@@ -441,7 +475,8 @@ class XooNIpsLogicSearchItem extends XooNIpsLogic
                     $search_cache_item->setVar('matchfor_item', 0, true);
                     $search_cache_item->setVar('matchfor_file', 1, true);
                     if (!$search_cache_item_handler->insert($search_cache_item)) {
-                        $error->add(XNPERR_SERVER_ERROR, "cannot insert search_cache_item");
+                        $error->add(XNPERR_SERVER_ERROR, 'cannot insert search_cache_item');
+
                         return;
                     }
                 }
@@ -450,7 +485,7 @@ class XooNIpsLogicSearchItem extends XooNIpsLogic
                 break;
             }
         }
+
         return;
     }
 }
-?>
