@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.1.2.9 $
+
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
@@ -24,11 +24,9 @@
 //  along with this program; if not, write to the Free Software              //
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
 // ------------------------------------------------------------------------- //
-if ( ! defined( 'XOOPS_ROOT_PATH' ) ) {
-  exit();
-}
+defined('XOOPS_ROOT_PATH') || exit('XOOPS root path not defined');
 
-require_once dirname( __FILE__ ).'/abstract_ranking.class.php';
+require_once __DIR__.'/abstract_ranking.class.php';
 
 /**
  * @brief data object of ranking downloaded item
@@ -36,61 +34,66 @@ require_once dirname( __FILE__ ).'/abstract_ranking.class.php';
  * @li getVar('item_id') :
  * @li getVar('count') :
  */
-class XooNIpsOrmRankingDownloadedItem extends XooNIpsTableObject {
-  function XooNIpsOrmRankingDownloadedItem() {
-    parent::XooNIpsTableObject();
-    $this->initVar( 'item_id', XOBJ_DTYPE_INT, 0, true );
-    $this->initVar( 'count', XOBJ_DTYPE_INT, 0, true );
-  }
+class XooNIpsOrmRankingDownloadedItem extends XooNIpsTableObject
+{
+    public function __construct()
+    {
+        parent::__construct();
+        $this->initVar('item_id', XOBJ_DTYPE_INT, 0, true);
+        $this->initVar('count', XOBJ_DTYPE_INT, 0, true);
+    }
 }
 
 /**
  * @brief handler object of ranking downloaded item
- *
  */
-class XooNIpsOrmRankingDownloadedItemHandler extends XooNIpsOrmAbstractRankingHandler {
-  function XooNIpsOrmRankingDownloadedItemHandler( &$db ) {
-    parent::XooNIpsTableObjectHandler( $db );
-    $this->__initHandler( 'XooNIpsOrmRankingDownloadedItem', 'xoonips_ranking_downloaded_item', 'item_id', false );
-    $this->_set_columns( array( 'item_id', 'count' ) );
-  }
-
-  /**
-   * insert/upldate/replace object
-   *
-   * @access public
-   * @param object &$obj
-   * @param bool $force force operation
-   * @return bool false if failed
-   */
-  function insert( &$obj, $force = false ) {
-    $item_id = $obj->get( 'item_id' );
-    if ( $item_id == 0 ) {
-      // ignore if item id is zero
-      return true;
+class XooNIpsOrmRankingDownloadedItemHandler extends XooNIpsOrmAbstractRankingHandler
+{
+    public function __construct(&$db)
+    {
+        parent::__construct($db);
+        $this->__initHandler('XooNIpsOrmRankingDownloadedItem', 'xoonips_ranking_downloaded_item', 'item_id', false);
+        $this->_set_columns(array('item_id', 'count'));
     }
-    return parent::insert( $obj, $force );
-  }
 
-  /**
-   * increment item downloaded counter for updating/rebuilding rankings
-   *
-   * @param int $item_id item id
-   * @param int $delta counter delta
-   * @return bool FALSE if failed
-   */
-  function increment( $item_id, $delta ) {
-    $obj =& $this->get( $item_id );
-    if ( is_object( $obj ) ) {
-      $delta += $obj->get( 'count' );
-    } else {
-      $obj =& $this->create();
-      $obj->set( 'item_id', $item_id );
+    /**
+     * insert/upldate/replace object.
+     *
+     * @param object &$obj
+     * @param bool   $force force operation
+     *
+     * @return bool false if failed
+     */
+    public function insert(&$obj, $force = false)
+    {
+        $item_id = $obj->get('item_id');
+        if (0 == $item_id) {
+            // ignore if item id is zero
+            return true;
+        }
+
+        return parent::insert($obj, $force);
+    }
+
+    /**
+     * increment item downloaded counter for updating/rebuilding rankings.
+     *
+     * @param int $item_id item id
+     * @param int $delta   counter delta
+     *
+     * @return bool FALSE if failed
+     */
+    public function increment($item_id, $delta)
+    {
+        $obj = &$this->get($item_id);
+        if (is_object($obj)) {
+            $delta += $obj->get('count');
+        } else {
+            $obj = &$this->create();
+            $obj->set('item_id', $item_id);
+        }
+        $obj->set('count', $delta);
+        // force insertion
+        return $this->insert($obj, true);
     }
-    $obj->set( 'count', $delta );
-    // force insertion
-    return $this->insert( $obj, true );
-  }
 }
-
-?>
