@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.1.4.1.2.7 $
+
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
@@ -25,10 +25,10 @@
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
 // ------------------------------------------------------------------------- //
 
-include_once XOOPS_ROOT_PATH . '/modules/xoonips/class/orm/file.class.php';
+require_once XOOPS_ROOT_PATH.'/modules/xoonips/class/orm/file.class.php';
 class XooNIpsXmlRpcTransformFile extends XooNIpsXmlRpcTransformElement
 {
-    function getObject($array) 
+    public function getObject($array)
     {
         $obj = new XooNIpsOrmFile();
         //$file_handler=&xoonips_getormhandler('xoonips', 'file');
@@ -37,18 +37,19 @@ class XooNIpsXmlRpcTransformFile extends XooNIpsXmlRpcTransformElement
         // filetype to file_type_id
         $file_type_handler = &xoonips_getormhandler('xoonips', 'file_type');
         $filetypes = &$file_type_handler->getObjects(new Criteria('name', $array['filetype']));
-        if (!$filetypes || count($filetypes) != 1) return false;
-        //
-        //
-        $unicode =& xoonips_getutility( 'unicode' );
+        if (!$filetypes || 1 != count($filetypes)) {
+            return false;
+        }
+
+        $unicode = &xoonips_getutility('unicode');
         $obj->assignVar('file_id', $array['id']);
         $obj->assignVar('file_type_id', $filetypes[0]->get('file_type_id'));
-        $obj->assignVar('original_file_name', $unicode->decode_utf8($array['originalname'],xoonips_get_server_charset(),'h') );
+        $obj->assignVar('original_file_name', $unicode->decode_utf8($array['originalname'], xoonips_get_server_charset(), 'h'));
         $obj->assignVar('file_size', intval($array['size']));
         $obj->assignVar('mime_type', $array['mimetype']);
-        $obj->assignVar('caption', $unicode->decode_utf8($array['caption'],xoonips_get_server_charset(),'h') );
+        $obj->assignVar('caption', $unicode->decode_utf8($array['caption'], xoonips_get_server_charset(), 'h'));
         $obj->assignVar('thumbnail_file', $array['thumbnail']);
+
         return $obj;
     }
 }
-?>
