@@ -1,8 +1,8 @@
 <?php
-// $Revision: 1.2.2.1.2.3 $
+
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
-//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
 //  http://xoonips.sourceforge.jp/                                           //
 // ------------------------------------------------------------------------- //
 //  This program is free software; you can redistribute it and/or modify     //
@@ -24,17 +24,12 @@
 //  along with this program; if not, write to the Free Software              //
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
 // ------------------------------------------------------------------------- //
-/**
- * definition file of PDF file search
- */
-// php-indent: disable
-$module['class_name']    = 'XoonipsPdf';
+
+// definition file of PDF file search.
+$module['class_name'] = 'XooNIpsFileSearchPluginPDF';
 $module['php_file_name'] = 'pdf.php';
-$module['name']          = 'pdf';
-$module['display_name']  = 'pdf';
-$module['byte_pattern']  = '%PDF-';
-$module['mime_type']     = array( 'application/pdf' );
-$module['extensions']    = array( 'pdf' );
-$module['version']       = '1.0';
-// php-indent: enable
-?>
+$module['name'] = 'pdf';
+$module['display_name'] = 'PDF';
+$module['mime_type'] = array('application/pdf');
+$module['extensions'] = array('pdf');
+$module['version'] = '2.0';
