@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.1.4.1.2.3 $
+
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
@@ -25,52 +25,53 @@
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
 // ------------------------------------------------------------------------- //
 
-if ( ! defined( 'XOOPS_ROOT_PATH' ) ) exit();
+defined('XOOPS_ROOT_PATH') || exit('XOOPS root path not defined');
 
 require_once XOOPS_ROOT_PATH.'/modules/xoonips/condefs.php';
 require_once XOOPS_ROOT_PATH.'/modules/xoonips/include/functions.php';
 
 /**
- * xoonips uninstall function
+ * xoonips uninstall function.
  *
  * @param object $xoopsMod module instance
+ *
  * @return bool false if failure
  */
-function xoops_module_uninstall_xoonips( $xoopsMod ) {
-  $mydirname = basename( dirname( __FILE__ ) );
+function xoops_module_uninstall_xoonips($xoopsMod)
+{
+    $mydirname = basename(__DIR__);
 
-  $uid = $GLOBALS['xoopsUser']->getVar( 'uid', 'n' );
-  $mid = $xoopsMod->getVar( 'mid', 'n' );
+    $uid = $GLOBALS['xoopsUser']->getVar('uid', 'n');
+    $mid = $xoopsMod->getVar('mid', 'n');
 
-  // get xoops administration handler
-  $admin_xoops_handler =& xoonips_gethandler( 'xoonips', 'admin_xoops' );
+    // get xoops administration handler
+    $admin_xoops_handler = &xoonips_gethandler('xoonips', 'admin_xoops');
 
-  // show original 'user' and 'login' blocks
-  $sys_blocks = array( 'user' => array(), 'login' => array() );
-  if ( defined( 'XOOPS_CUBE_LEGACY' ) ) {
-    // for XOOPS Cube Legacy 2.1
-    $sys_blocks['user'][] = array( 'legacy', 'b_legacy_usermenu_show' );
-    $sys_blocks['login'][] = array( 'user', 'b_user_login_show' );
-  }
-  $sys_blocks['user'][] = array( 'system', 'b_system_user_show' );
-  $sys_blocks['login'][] = array( 'system', 'b_system_login_show' );
-  foreach( $sys_blocks as $type => $sys_type_blocks ) {
-    foreach ( $sys_type_blocks as $sys_block ) {
-      list( $dirname, $show_func ) = $sys_block;
-      $sysmid = $admin_xoops_handler->getModuleId( $dirname );
-      if ( $sysmid === false ) {
-        continue; // module not found
-      }
-      $bids = $admin_xoops_handler->getBlockIds( $sysmid, $show_func );
-      foreach ( $bids as $bid ) {
-        $admin_xoops_handler->setBlockPosition( $bid, true, 0, 0 );
-      }
-      if ( count( $bids ) != 0 ) {
-        break; // found this type's block
-      }
+    // show original 'user' and 'login' blocks
+    $sys_blocks = array('user' => array(), 'login' => array());
+    if (defined('XOOPS_CUBE_LEGACY')) {
+        // for XOOPS Cube Legacy 2.1
+        $sys_blocks['user'][] = array('legacy', 'b_legacy_usermenu_show');
+        $sys_blocks['login'][] = array('user', 'b_user_login_show');
+    }
+    $sys_blocks['user'][] = array('system', 'b_system_user_show');
+    $sys_blocks['login'][] = array('system', 'b_system_login_show');
+    foreach ($sys_blocks as $type => $sys_type_blocks) {
+        foreach ($sys_type_blocks as $sys_block) {
+            list($dirname, $show_func) = $sys_block;
+            $sysmid = $admin_xoops_handler->getModuleId($dirname);
+            if (false === $sysmid) {
+                continue; // module not found
+            }
+            $bids = $admin_xoops_handler->getBlockIds($sysmid, $show_func);
+            foreach ($bids as $bid) {
+                $admin_xoops_handler->setBlockPosition($bid, true, 0, 0);
+            }
+            if (0 != count($bids)) {
+                break; // found this type's block
+            }
+        }
     }
-  }
-  return true;
-}
 
-?>
+    return true;
+}
